Learn R Programming

SumcaVer1 (version 0.1.0)

mspe_MS_LOGISTIC_JLW: Model selection MSPE estimation in mixed logistic model using jackknife method.Calculate the model selection mspe of mixed logistic model using jackknife method.

Description

Model selection MSPE estimation in mixed logistic model using jackknife method.Calculate the model selection mspe of mixed logistic model using jackknife method.

Usage

mspe_MS_LOGISTIC_JLW(m, p, ni, X, beta, A, R)

Value

Par1: return estimation of model parameters of the complete model

Par2: return estimation of model parameters of the reduced model

MSPE: return empirical MSPE of small area predictor

mspe.JLW: return mspe of small area predictor using the jackknife method

RB.JLW: return relative bias (RB) of mspe of small area predictor using the jackknife method

BIC: return BIC of the complete and reduced models

Arguments

m

number of small areas

p

number of complete model parameters

ni

sample size of each small area

X

covariates for the complete model

beta

regression coefficients of the complete model

A

variance of area-specific random effects

R

number of simulation runs

Examples

Run this code
mspe_MS_LOGISTIC_JLW(20,3,2,
matrix(runif(60,0,1),nrow=20,byrow=TRUE),c(1,1,1),10,2)

Run the code above in your browser using DataLab