mspe_MS_LOGISTIC_SUMCA: Model selection MSPE estimation in mixed logistic model using SUMCA method. Calculate the model selection mspe of mixed logistic model using SUMCA method.
Description
Model selection MSPE estimation in mixed logistic model using SUMCA method. Calculate the model selection mspe of mixed logistic model using SUMCA method.
Usage
mspe_MS_LOGISTIC_SUMCA(m, p, ni, X, beta, A, K, R)
Value
Par1: return estimation of model parameters of the complete model
Par2: return estimation of model parameters of the reduced model
MSPE: return empirical MSPE of small area predictor
mspe.Sumca: return mspe of small area predictor using the SUMCA method
RB.SUMCA: return relative bias (RB) of mspe of small area predictor using the SUMCA method
BIC: return BIC of the complete and reduced models