Learn R Programming

SumcaVer1 (version 0.1.0)

mspe_PMS_FH_DHM: Post model selection MSPE estimation in FH model using Datta-Hall-Mandal method. Calculate the post-model selection mspe of Fay-Herriot model using Datta-Hall-Mandal method.

Description

Post model selection MSPE estimation in FH model using Datta-Hall-Mandal method. Calculate the post-model selection mspe of Fay-Herriot model using Datta-Hall-Mandal method.

Usage

mspe_PMS_FH_DHM(m, p, X, beta, A, D, R)

Value

Par: return estimation of model parameters

MSPE.TRUE.Final: return empirical MSPE of small area predictor

mspe.DHM.Final: return mspe of small area predictor using the Datta-Hall-Mandal method

RB.DHM: return relative bias (RB) of mspe of small area predictor using the Datta-Hall-Mandal method

Rate: return the probability of rejection (nominal level= 0.2)

Arguments

m

number of small areas

p

number of fixed model parameters

X

covariates

beta

regression coefficients

A

variance of area-specific random effects

D

sampling variance

R

number of simulation runs

Examples

Run this code
mspe_PMS_FH_DHM(20,3,matrix(runif(60,0,1),nrow=20,byrow=TRUE),
c(1,1,1),10,2.5,10)

Run the code above in your browser using DataLab