mspe_PMS_FH_SUMCA: Post model selection MSPE estimation in FH model using SUMCA method. Calculate the post-model selection mspe of Fay-Herriot model using SUMCA method.
Description
Post model selection MSPE estimation in FH model using SUMCA method. Calculate the post-model selection mspe of Fay-Herriot model using SUMCA method.
Usage
mspe_PMS_FH_SUMCA(m, p, X, beta, A, D, K, R)
Value
Par: return estimation of model parameters
MSPE.TRUE.Final: return empirical MSPE of small area predictor
mspe.Sumca.Final: return mspe of small area predictor using the SUMCA method
RB.SUMCA: return relative bias (RB) of mspe of small area predictor using the SUMCA method