mspe_MS_LOGISTIC_JLW: Model selection MSPE estimation in mixed logistic model using jackknife method.Calculate the model selection mspe of mixed logistic model using jackknife method.
Description
Model selection MSPE estimation in mixed logistic model using jackknife method.Calculate the model selection mspe of mixed logistic model using jackknife method.
Usage
mspe_MS_LOGISTIC_JLW(m, p, ni, X, beta, A, R)
Value
Par1: return estimation of model parameters of the complete model
Par2: return estimation of model parameters of the reduced model
MSPE: return empirical MSPE of small area predictor
mspe.JLW: return mspe of small area predictor using the jackknife method
RB.JLW: return relative bias (RB) of mspe of small area predictor using the jackknife method
BIC: return BIC of the complete and reduced models